@@ -59,7 +59,8 @@ setRefClass("H2OConnectionMutableState",
 #' @slot insecure Set this to TRUE to disable SSL certificate checking.
 #' @slot username Username to login with.
 #' @slot password Password to login with.
-#' @slot cluster_name Cluster to login to.
+#' @slot cluster_id Cluster to login to. Used for Steam connections
+#' @slot cookies Cookies to add to request
 #' @slot mutable An \code{H2OConnectionMutableState} object to hold the mutable state for the H2O connection.
 #' @aliases H2OConnection
 #' @export
@@ -67,7 +68,8 @@ setClass("H2OConnection",
          representation(ip="character", port="numeric", proxy="character",
                         https="logical", insecure="logical",
                         username="character", password="character",
-                        cluster_name="character",
+                        cluster_id="numeric",
+                        cookies="character",
                         mutable="H2OConnectionMutableState"),
          prototype(ip           = NA_character_,
                    port         = NA_integer_,
@@ -76,7 +78,8 @@ setClass("H2OConnection",
                    insecure     = FALSE,
                    username     = NA_character_,
                    password     = NA_character_,
-                   cluster_name = NA_character_,
+                   cluster_id   = NA_integer_,
+                   cookies      = NA_character_,
                    mutable      = new("H2OConnectionMutableState")))
 
 setClassUnion("H2OConnectionOrNULL", c("H2OConnection", "NULL"))
@@ -360,9 +363,9 @@ setClass("H2OModelMetrics",
 #' @export
 setMethod("show", "H2OModelMetrics", function(object) {
     cat(class(object), ": ", object@algorithm, "\n", sep="")
-    if( object@on_train ) cat("** Reported on training data. **\n")
-    if( object@on_valid ) cat("** Reported on validation data. **\n")
-    if( object@on_xval ) cat("** Reported on cross-validation data. **\n")
+    if( object@on_train & object@algorithm != "pca" ) cat("** Reported on training data. **\n")
+    if( object@on_valid & object@algorithm != "pca" ) cat("** Reported on validation data. **\n")
+    if( object@on_xval & object@algorithm != "pca"  ) cat("** Reported on cross-validation data. **\n")
     if( !is.null(object@metrics$description) ) cat("** ", object@metrics$description, " **\n\n", sep="")
     else                                       cat("\n")
 })
@@ -499,6 +502,8 @@ setMethod("show", "H2ODimReductionMetrics", function(object) {
       cat("\nMisclassification Error (Categorical): ", m$caterr)
       cat("\nNumber of Numeric Entries: ", m$numcnt)
       cat("\nNumber of Categorical Entries: ", m$catcnt)
+    }else if(object@algorithm == "pca" ) {
+        cat("No model metrics available for PCA")
     }
   } else print(NULL)
 })
