@@ -127,9 +127,14 @@
 
   tmp <- NULL
   header <- c('Connection' = 'close')
-  if (!is.na(conn@cluster_name)) {
-    header['X-Cluster'] = conn@cluster_name
+  if (!is.na(conn@cluster_id)) {
+    header['X-Cluster'] = conn@cluster_id
   }
+
+  if(!is.na(conn@cookies)) {
+    header['Cookie'] = paste0(conn@cookies, collapse=';')
+  }
+
   if ((method == "GET") || (method == "DELETE")) {
     h <- basicHeaderGatherer()
     t <- basicTextGatherer(.mapUnicode = FALSE)
