@@ -24,7 +24,8 @@
 #' @param insecure (Optional) Set this to TRUE to disable SSL certificate checking.
 #' @param username (Optional) Username to login with.
 #' @param password (Optional) Password to login with.
-#' @param cluster_name (Optional) Cluster to login to.
+#' @param cluster_id (Optional) Cluster to login to. Used for Steam connections.
+#' @param cookies (Optional) Vector(or list) of cookies to add to request.
 #' @return this method will load it and return a \code{H2OConnection} object containing the IP address and port number of the H2O server.
 #' @note Users may wish to manually upgrade their package (rather than waiting until being prompted), which requires
 #' that they fully uninstall and reinstall the H2O package, and the H2O client package. You must unload packages running
@@ -53,7 +54,7 @@ h2o.init <- function(ip = "localhost", port = 54321, startH2O = TRUE, forceDL =
                      enable_assertions = TRUE, license = NULL, nthreads = -2,
                      max_mem_size = NULL, min_mem_size = NULL,
                      ice_root = tempdir(), strict_version_check = TRUE, proxy = NA_character_,
-                     https = FALSE, insecure = FALSE, username = NA_character_, password = NA_character_, cluster_name = NA_character_) {
+                     https = FALSE, insecure = FALSE, username = NA_character_, password = NA_character_, cluster_id = NA_integer_, cookies = NA_character_) {
   if(!is.character(ip) || length(ip) != 1L || is.na(ip) || !nzchar(ip))
     stop("`ip` must be a non-empty character string")
   if(!is.numeric(port) || length(port) != 1L || is.na(port) || port < 0 || port > 65536)
@@ -96,8 +97,11 @@ h2o.init <- function(ip = "localhost", port = 54321, startH2O = TRUE, forceDL =
     stop("`password` must be a character string or NA_character_")
   if (is.na(username) != is.na(password))
     stop("Must provide both `username` and `password`")
-  if (!is.character(cluster_name) || !nzchar(cluster_name))
-    stop("`cluster_name` must be a character string or NA_character_")
+  if (!is.na(cluster_id) && 
+      (!is.numeric(cluster_id) || cluster_id < 0))
+    stop("`cluster_id` must be an integer value greater than 0")
+  if (!is.na(cookies) && (!is.vector(cookies)))
+    stop("`cookies` must be a vector of cookie values")
 
   if ((R.Version()$major == "3") && (R.Version()$minor == "1.0")) {
     stop("H2O is not compatible with R 3.1.0\n",
@@ -113,7 +117,7 @@ h2o.init <- function(ip = "localhost", port = 54321, startH2O = TRUE, forceDL =
 
   warnNthreads <- FALSE
   tmpConn <- new("H2OConnection", ip = ip, port = port, proxy = proxy, https = https, insecure = insecure, 
-    username = username, password = password, cluster_name = cluster_name)
+    username = username, password = password, cluster_id = cluster_id, cookies = cookies)
   if (!h2o.clusterIsUp(tmpConn)) {
     if (!startH2O)
       stop("Cannot connect to H2O server. Please check that H2O is running at ", h2o.getBaseURL(tmpConn))
@@ -154,7 +158,7 @@ h2o.init <- function(ip = "localhost", port = 54321, startH2O = TRUE, forceDL =
   }
 
   conn <- new("H2OConnection", ip = ip, port = port, proxy = proxy, https = https, insecure = insecure, 
-    username = username, password = password, cluster_name = cluster_name)
+    username = username, password = password, cluster_id = cluster_id, cookies = cookies)
   assign("SERVER", conn, .pkg.env)
   cat(" Connection successful!\n\n")
   h2o.clusterInfo()
@@ -531,15 +535,10 @@ h2o.clusterStatus <- function() {
 # This function returns the path to the Java executable if it exists
 # X) NO: Fails on Windows.  Check for Java in user's PATH
 # 2) Check for JAVA_HOME environment variable
-# 3) If Windows, check standard install locations in Program Files folder. Warn if JRE found, but not JDK since H2O requires JDK to run.
+# 3) If Windows, check standard install locations in Program Files folder. Will look for JRE.
 # 4) Check for Java in user's PATH.
-# 5) When all fails, stop and prompt user to download JDK from Oracle website.
+# 5) When all fails, stop and prompt user to download JRE from Oracle website.
 .h2o.checkJava <- function() {
-# For reasons unknown, on Windows Sys.which("java") returns the Windows archaic
-# built-in Java, even with a good recent JDK on the PATH.  This Java version is
-# totally broken.  Try it last.
-#  if(nzchar(Sys.which("java")))
-#    Sys.which("java")
   if(nzchar(Sys.getenv("JAVA_HOME"))) {
     if(.Platform$OS.type == "windows") { file.path(Sys.getenv("JAVA_HOME"), "bin", "java.exe") }
     else                               { file.path(Sys.getenv("JAVA_HOME"), "bin", "java") }
@@ -549,24 +548,18 @@ h2o.clusterStatus <- function() {
     prog_folder <- c("Program Files", "Program Files (x86)")
     for(prog in prog_folder) {
       prog_path <- file.path("C:", prog, "Java")
-      jdk_folder <- list.files(prog_path, pattern = "jdk")
+      java_folder <- list.files(prog_path)
 
-      for(jdk in jdk_folder) {
-        path <- file.path(prog_path, jdk, "bin", "java.exe")
+      for(java in java_folder) {
+        path <- file.path(prog_path, java, "bin", "java.exe")
         if(file.exists(path)) return(path)
       }
     }
-
-    # Check for existence of JRE and warn user
-    for(prog in prog_folder) {
-      path <- file.path("C:", prog, "Java", "jre7", "bin", "java.exe")
-      if(file.exists(path)) warning("Found JRE at ", path, " but H2O requires the JDK to run")
-    }
   }
   else if(nzchar(Sys.which("java")))
     Sys.which("java")
   else
-    stop("Cannot find Java. Please install the latest JDK from\n",
+    stop("Cannot find Java. Please install the latest JRE from\n",
          "http://www.oracle.com/technetwork/java/javase/downloads/index.html")
 }
 
