@@ -8,16 +8,13 @@
 #'        variables in the model.
 #' @param x (Optional) A vector containing the data columns on
 #'        which k-means operates.
-#' @param k The number of clusters. Must be between 1 and
-#'        1e7 inclusive. k may be omitted if the user specifies the
-#'        initial centers in the init parameter. If k is not omitted,
-#'        in this case, then it should be equal to the number of
-#'        user-specified centers.
+#' @param k The max. number of clusters. If estimate_k is disabled, the model will find k centroids, otherwise it will find up to k centroids.
+#' @param estimate_k Whether to estimate the number of clusters (<=k) iteratively and deterministically.
 #' @param model_id (Optional) The unique id assigned to the resulting model. If
 #'        none is given, an id will automatically be generated.
 #' @param ignore_const_cols A logical value indicating whether or not to ignore all the constant columns in the training frame.
-#' @param max_iterations The maximum number of iterations allowed. Must be between 0
-#         and 1e6 inclusive.
+#' @param max_iterations Maximum training iterations (if estimate_k is enabled, then this is for each inner Lloyds iteration).
+#'        Must be between 0 and 1e6 inclusive.
 #' @param standardize Logical, indicates whether the data should be
 #'        standardized before running k-means.
 #' @param init A character string that selects the initial set of k cluster
@@ -37,6 +34,8 @@
 #'        stratify the folds based on the response variable, for classification problems.
 #' @param keep_cross_validation_predictions Whether to keep the predictions of the cross-validation models
 #' @param keep_cross_validation_fold_assignment Whether to keep the cross-validation fold assignment.
+#' @param categorical_encoding Encoding scheme for categorical features
+#'        Can be one of "AUTO", "Enum", "OneHotInternal", "OneHotExplicit", "Binary", "Eigen". Default is "AUTO", which is "Enum".
 #' @param max_runtime_secs Maximum allowed runtime in seconds for model training. Use 0 to disable.
 #' @return Returns an object of class \linkS4class{H2OClusteringModel}.
 #' @seealso \code{\link{h2o.cluster_sizes}}, \code{\link{h2o.totss}}, \code{\link{h2o.num_iterations}},
@@ -51,10 +50,12 @@
 #' h2o.kmeans(training_frame = prostate.hex, k = 10, x = c("AGE", "RACE", "VOL", "GLEASON"))
 #' }
 #' @export
-h2o.kmeans <- function(training_frame, x, k,
+h2o.kmeans <- function(training_frame, x,
+                       k,
+                       estimate_k = FALSE,
                        model_id,
                        ignore_const_cols = TRUE,
-                       max_iterations = 1000,
+                       max_iterations = 10,
                        standardize = TRUE,
                        init = c("Furthest","Random", "PlusPlus"),
                        seed,
@@ -63,6 +64,7 @@ h2o.kmeans <- function(training_frame, x, k,
                        fold_assignment = c("AUTO","Random","Modulo","Stratified"),
                        keep_cross_validation_predictions = FALSE,
                        keep_cross_validation_fold_assignment = FALSE,
+                       categorical_encoding=c("AUTO", "Enum", "OneHotInternal", "OneHotExplicit", "Binary", "Eigen"),
                        max_runtime_secs=0)
 {
   # Training_frame may be a key or an H2OFrame object
@@ -78,6 +80,8 @@ h2o.kmeans <- function(training_frame, x, k,
     parms$ignored_columns <- .verify_datacols(training_frame, x)$cols_ignore
   if(!missing(k))
     parms$k <- k
+  if(!missing(estimate_k))
+    parms$estimate_k <- estimate_k
   parms$training_frame <- training_frame
   if(!missing(model_id))
     parms$model_id <- model_id
@@ -97,6 +101,7 @@ h2o.kmeans <- function(training_frame, x, k,
   if( !missing(fold_assignment) )           parms$fold_assignment        <- fold_assignment
   if( !missing(keep_cross_validation_predictions) )  parms$keep_cross_validation_predictions  <- keep_cross_validation_predictions
   if( !missing(keep_cross_validation_fold_assignment) )  parms$keep_cross_validation_fold_assignment  <- keep_cross_validation_fold_assignment
+  if(!missing(categorical_encoding)) parms$categorical_encoding <- categorical_encoding
   if(!missing(max_runtime_secs)) parms$max_runtime_secs <- max_runtime_secs
 
   # Check if init is an acceptable set of user-specified starting points
