@@ -3,7 +3,7 @@
 #' Builds a Random Forest Model on an H2OFrame
 #'
 #' @param x A vector containing the names or indices of the predictor variables
-#'        to use in building the RF model.
+#'        to use in building the RF model. If x is missing,then all columns except y are used.
 #' @param y The name or index of the response variable. If the data does not
 #'        contain a header, this is the column index number starting at 1, and
 #'        increasing from left to right. (The response must be either an integer
@@ -18,56 +18,56 @@
 #' @param mtries Number of variables randomly sampled as candidates at each split.
 #'        If set to -1, defaults to sqrt{p} for classification, and p/3 for regression,
 #'        where p is the number of predictors.
-#' @param col_sample_rate_change_per_level Relative change of the column sampling rate for every level (from 0.0 to 2.0)
-#' @param sample_rate Row sample rate per tree (from \code{0.0} to \code{1.0})
-#' @param sample_rate_per_class Row sample rate per tree per class (one per class, from \code{0.0} to \code{1.0})
-#' @param col_sample_rate_per_tree Column sample rate per tree (from \code{0.0} to \code{1.0})
+#' @param col_sample_rate_change_per_level Relative change of the column sampling rate for every level (from 0.0 to 2.0).  Default is 1.
+#' @param sample_rate Row sample rate per tree (from \code{0.0} to \code{1.0}).  Default is 0.632.
+#' @param sample_rate_per_class Row sample rate per tree per class (one per class, from \code{0.0} to \code{1.0}).
+#' @param col_sample_rate_per_tree Column sample rate per tree (from \code{0.0} to \code{1.0}).  Default is 1.
 #' @param build_tree_one_node Run on one node only; no network overhead but
-#'        fewer cpus used.  Suitable for small datasets.
-#' @param ntrees A nonnegative integer that determines the number of trees to
-#'        grow.
-#' @param max_depth Maximum depth to grow the tree.
-#' @param min_rows Minimum number of rows to assign to teminal nodes.
-#' @param nbins For numerical columns (real/int), build a histogram of (at least) this many bins, then split at the best point.
+#'        fewer cpus used.  Suitable for small datasets.  Default is \code{FALSE}.
+#' @param ntrees A nonnegative integer that determines the number of trees to grow.  Default is 50.
+#' @param max_depth Maximum depth to grow the tree.  Default is 5.
+#' @param min_rows Minimum number of rows to assign to teminal nodes.  Default is 10.
+#' @param nbins For numerical columns (real/int), build a histogram of (at least) this many bins, then split at the best point.  Default is 20.
 #' @param nbins_top_level For numerical columns (real/int), build a histogram of (at most) this many bins at the root
-#'        level, then decrease by factor of two per level.
+#'        level, then decrease by factor of two per level.  Default is 1024.
 #' @param nbins_cats For categorical columns (factors), build a histogram of this many bins, then split at the best point.
-#'        Higher values can lead to more overfitting.
-#' @param binomial_double_trees For binary classification: Build 2x as many trees (one per class) - can lead to higher accuracy.
-#' @param balance_classes logical, indicates whether or not to balance training
-#'        data class counts via over/under-sampling (for imbalanced data)
+#'        Higher values can lead to more overfitting.  Default is 1024.
+#' @param binomial_double_trees For binary classification: Build 2x as many trees (one per class) - can lead to higher accuracy.  Default is \code{FALSE}.
+#' @param balance_classes logical, indicates whether or not to balance training data class
+#'        counts via over/under-sampling (for imbalanced data).  Default is \code{FALSE}.
 #' @param class_sampling_factors Desired over/under-sampling ratios per class (in lexicographic
 #'        order). If not specified, sampling factors will be automatically computed to obtain class
 #'        balance during training. Requires balance_classes.
 #' @param max_after_balance_size Maximum relative size of the training data after balancing class counts (can be less
-#'        than 1.0). Ignored if balance_classes is FALSE, which is the default behavior.
+#'        than 1.0). Ignored if balance_classes is FALSE, which is the default behavior.  Default is 5.
 #' @param seed Seed for random numbers (affects sampling) - Note: only
-#'        reproducible when running single threaded
-#' @param offset_column Specify the offset column.
-#' @param weights_column Specify the weights column.
-#' @param nfolds (Optional) Number of folds for cross-validation.
-#' @param fold_column (Optional) Column with cross-validation fold index assignment per observation
+#'        reproducible when running single threaded.
+#' @param offset_column Specify the offset column.  Defaults to \code{NULL}.
+#' @param weights_column Specify the weights column.  Defaults to \code{NULL}.
+#' @param nfolds (Optional) Number of folds for cross-validation.  Default is 0 (no cross-validation).
+#' @param fold_column (Optional) Column with cross-validation fold index assignment per observation.  Defaults to NULL.
 #' @param fold_assignment Cross-validation fold assignment scheme, if fold_column is not
 #'        specified, must be "AUTO", "Random",  "Modulo", or "Stratified".  The Stratified option will 
 #'        stratify the folds based on the response variable, for classification problems.
-#' @param keep_cross_validation_predictions Whether to keep the predictions of the cross-validation models
-#' @param keep_cross_validation_fold_assignment Whether to keep the cross-validation fold assignment.
-#' @param score_each_iteration Attempts to score each tree.
-#' @param score_tree_interval Score the model after every so many trees. Disabled if set to 0.
-#' @param stopping_rounds Early stopping based on convergence of stopping_metric.
+#' @param keep_cross_validation_predictions Whether to keep the predictions of the cross-validation models.  Default is \code{FALSE}.
+#' @param keep_cross_validation_fold_assignment Whether to keep the cross-validation fold assignment.  Default is \code{FALSE}.
+#' @param score_each_iteration Attempts to score each tree.  Default is \code{FALSE}.
+#' @param score_tree_interval Score the model after every so many trees. Default is 0 (disabled).
+#' @param stopping_rounds Early stopping based on convergence of stopping_metric.  Default is 0 (disabled).
 #'        Stop if simple moving average of length k of the stopping_metric does not improve
 #'        (by stopping_tolerance) for k=stopping_rounds scoring events.
-#'        Can only trigger after at least 2k scoring events. Use 0 to disable.
+#'        Can only trigger after at least 2k scoring events.
 #' @param stopping_metric Metric to use for convergence checking, only for _stopping_rounds > 0
 #'        Can be one of "AUTO", "deviance", "logloss", "MSE", "AUC", "misclassification", or "mean_per_class_error".
 #' @param stopping_tolerance Relative tolerance for metric-based stopping criterion (if relative
-#'        improvement is not at least this much, stop)
-#' @param max_runtime_secs Maximum allowed runtime in seconds for model training. Use 0 to disable.
-#' @param min_split_improvement Minimum relative improvement in squared error reduction for a split to happen.
+#'        improvement is not at least this much, stop).  Default is 0.001.
+#' @param max_runtime_secs Maximum allowed runtime in seconds for model training. Default is 0 (disabled).
+#' @param min_split_improvement Minimum relative improvement in squared error reduction for a split to happen.  Default is 1e-5 and the value must be >=0.
 #' @param histogram_type What type of histogram to use for finding optimal split points
 #'        Can be one of "AUTO", "UniformAdaptive", "Random", "QuantilesGlobal" or "RoundRobin". Note that H2O supports
 #'        extremely randomized trees with the "Random" option.
-#' @param ... (Currently Unimplemented)
+#' @param categorical_encoding Encoding scheme for categorical features
+#'        Can be one of "AUTO", "Enum", "OneHotInternal", "OneHotExplicit", "Binary", "Eigen". Default is "AUTO", which is "Enum".
 #' @return Creates a \linkS4class{H2OModel} object of the right type.
 #' @seealso \code{\link{predict.H2OModel}} for prediction.
 #' @export
@@ -86,7 +86,7 @@ h2o.randomForest <- function(x, y, training_frame,
                              max_depth = 20,
                              min_rows = 1,
                              nbins = 20,
-                             nbins_top_level,
+                             nbins_top_level = 1024,
                              nbins_cats = 1024,
                              binomial_double_trees = FALSE,
                              balance_classes = FALSE,
@@ -102,14 +102,23 @@ h2o.randomForest <- function(x, y, training_frame,
                              keep_cross_validation_fold_assignment = FALSE,
                              score_each_iteration = FALSE,
                              score_tree_interval = 0,
-                             stopping_rounds=0,
-                             stopping_metric=c("AUTO", "deviance", "logloss", "MSE", "AUC", "misclassification", "mean_per_class_error"),
-                             stopping_tolerance=1e-3,
-                             max_runtime_secs=0,
-                             min_split_improvement,
-                             histogram_type=c("AUTO","UniformAdaptive","Random","QuantilesGlobal","RoundRobin")
+                             stopping_rounds = 0,
+                             stopping_metric = c("AUTO", "deviance", "logloss", "MSE", "AUC", "misclassification", "mean_per_class_error"),
+                             stopping_tolerance = 1e-3,
+                             max_runtime_secs = 0,
+                             min_split_improvement = 1e-5,
+                             histogram_type = c("AUTO","UniformAdaptive","Random","QuantilesGlobal","RoundRobin"),
+                             categorical_encoding=c("AUTO", "Enum", "OneHotInternal", "OneHotExplicit", "Binary", "Eigen")
                              )
 {
+  #If x is missing, then assume user wants to use all columns as features.
+  if(missing(x)){
+    if(is.numeric(y)){
+      x <- setdiff(col(training_frame),y)
+    }else{
+      x <- setdiff(colnames(training_frame),y)
+    }
+  }
   # Training_frame and validation_frame may be a key or an H2OFrame object
   if (!is.H2OFrame(training_frame))
     tryCatch(training_frame <- h2o.getFrame(training_frame),
@@ -191,6 +200,7 @@ h2o.randomForest <- function(x, y, training_frame,
   if(!missing(max_runtime_secs)) parms$max_runtime_secs <- max_runtime_secs
   if(!missing(min_split_improvement)) parms$min_split_improvement <- min_split_improvement
   if(!missing(histogram_type)) parms$histogram_type <- histogram_type
+  if(!missing(categorical_encoding)) parms$categorical_encoding <- categorical_encoding
 
   .h2o.modelJob('drf', parms)
 }
